Solvable

Trait Solvable 

pub trait Solvable {
    // Required method
    fn solve(
        &mut self,
        input: ChallengeInput,
        task_index: usize,
    ) -> Result<bool>;
}

Required Methods

fn solve(&mut self, input: ChallengeInput, task_index: usize) -> Result<bool>

Attempts to solve a part of the challenge with the given input. Returns true if the part is successfully solved, otherwise false.

Implementors