pub enum ChallengeCommand {
Start(Challenge),
NextTask,
PreviousTask,
SolveOption(usize),
Finish(Option<ChallengeResult>),
}Expand description
Represents challenge-level commands that can be executed on the game state.
Variants
Start(Challenge)
NextTask
Command to move to the next task within a challenge.
PreviousTask
Command to move to the previous task within a challenge.
SolveOption(usize)
Command to solve a multiple choice option.
Finish(Option<ChallengeResult>)
Command to finish the challenge with a custom result.